@@ -3,7 +3,7 @@ package Assert::Refute::Build;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = 0.0305;
+our $VERSION = 0.04;
 
 =head1 NAME
 
@@ -48,7 +48,7 @@ This can be later used inside production code to check a condition:
 
     my $log = $oo_check->apply(137);
     $log->is_passing; # nope
-    $log->as_tap;     # get details
+    $log->get_tap;    # get details
 
 This call will create a prototyped function is_everything(...) in the calling
 package, with C<args> positional parameters and an optional human-readable
@@ -130,6 +130,9 @@ with parentheses.
 
 =back
 
+The name must not start with C<set_>, C<get_>, or C<do_>.
+Also colliding with a previously defined name would case an exception.
+
 =cut
 
 my %Backend;
@@ -144,6 +147,9 @@ sub build_refute(@) { ## no critic # Moose-like DSL for the win!
 
     my $class = "Assert::Refute::Exec";
 
+    if ($name =~ /^(get_|set_|do_)/) {
+        croak "build_refute(): fucntion name shall not start with get_, set_, or do_";
+    };
     if (my $backend = ( $class->can($name) ? $class : $Backend{$name} ) ) {
         croak "build_refute(): '$name' already registered by $backend";
     };
