@@ -3,7 +3,7 @@ package Assert::Refute::Exec;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = 0.0305;
+our $VERSION = 0.04;
 
 =head1 NAME
 
@@ -27,9 +27,9 @@ See L<Assert::Refute::Contract> for contract I<definition>.
     # .......
     $c->done_testing; # no more refute after this
 
-    $c->count;      # how many tests were run
-    $c->is_passing; # did any of them fail?
-    $c->as_tap;     # return printable summary in familiar format
+    $c->get_count;    # how many tests were run
+    $c->is_passing;   # did any of them fail?
+    $c->get_tap;      # return printable summary in familiar format
 
 =cut
 
@@ -53,7 +53,7 @@ my $ERROR_DONE = "done_testing was called, no more changes may be added";
 
 =over
 
-=item * indent - log indentation (will be shown as 4 spaces in C<as_tap>);
+=item * indent - log indentation (will be shown as 4 spaces in C<get_tap>);
 
 =back
 
@@ -87,14 +87,14 @@ sub refute {
 
     $msg = $msg ? " - $msg" : '';
     my $n = ++$self->{count};
-    $self->add_result( $n, $cond );
+    $self->set_result( $n, $cond );
 
     if ($cond) {
-        $self->log_message( 0, -1, "not ok $n$msg" );
-        $self->log_message( 0,  1, $cond ) unless $cond eq 1;
+        $self->do_log( 0, -1, "not ok $n$msg" );
+        $self->do_log( 0,  1, $cond ) unless $cond eq 1;
         return 0;
     } else {
-        $self->log_message( 0,  0, "ok $n$msg" );
+        $self->do_log( 0,  0, "ok $n$msg" );
         return 1;
     };
 };
@@ -118,13 +118,13 @@ References are explained to depth 1.
 sub diag {
     my $self = shift;
 
-    $self->log_message( 0, 1, join " ", map { to_scalar($_) } @_ );
+    $self->do_log( 0, 1, join " ", map { to_scalar($_) } @_ );
 };
 
 sub note {
     my $self = shift;
 
-    $self->log_message( 0, 2, join " ", map { to_scalar($_) } @_ );
+    $self->do_log( 0, 2, join " ", map { to_scalar($_) } @_ );
 };
 
 =head3 done_testing
@@ -145,16 +145,16 @@ sub done_testing {
 
     if ($exception) {
         delete $self->{done};
-        $self->{last_error} = $exception;
+        $self->{has_error} = $exception;
         # Make sure there *is* a failing test on the outside
         $self->refute( $exception, "unexpected exception: $exception" );
-        $self->log_message( 0, 1, "Looks like test execution was interrupted" );
+        $self->do_log( 0, 1, "Looks like test execution was interrupted" );
     } elsif ($self->{done}) {
         $self->_croak( $ERROR_DONE )
     } else {
-        $self->log_message(0, 0, "1..$self->{count}");
+        $self->do_log(0, 0, "1..$self->{count}");
     };
-    $self->log_message(0, 1,
+    $self->do_log(0, 1,
         "Looks like $self->{failed} tests of $self->{count} have failed")
             if $self->{failed};
 
@@ -201,7 +201,7 @@ sub subcontract {
     $self->refute( $stop, "$msg (subtest)" );
     if ($stop) {
         my $log = $exec->get_log;
-        $self->log_message( $_->[0]+1, $_->[1], $_->[2] )
+        $self->do_log( $_->[0]+1, $_->[1], $_->[2] )
             for @$log;
     };
 };
@@ -229,16 +229,16 @@ Tell whether the contract is passing or not.
 sub is_passing {
     my $self = shift;
 
-    return !$self->{failed} && !$self->{last_error};
+    return !$self->{failed} && !$self->{has_error};
 };
 
-=head3 count
+=head3 get_count
 
 How many tests have been executed.
 
 =cut
 
-sub count {
+sub get_count {
     my $self = shift;
     return $self->{count};
 };
@@ -254,7 +254,7 @@ sub get_tests {
     return $self->{list} ? @{ $self->{list} } : ();
 };
 
-=head3 result( $id )
+=head3 get_result( $id )
 
 Returns result of test denoted by $id, dies if such test was never performed.
 The result is false for passing tests and whatever the reason for failure was
@@ -262,7 +262,7 @@ for failing ones.
 
 =cut
 
-sub result {
+sub get_result {
     my ($self, $n) = @_;
 
     $self->_croak( "Test $n has never been performed" )
@@ -271,34 +271,25 @@ sub result {
     return $self->{fail}{$n} || 0;
 };
 
-=head3 has_died
-
-Returns true if contract execution was ever interrupted by exception.
-
-=cut
-
-# TODO like, do we need this if we have last_error?
-*has_died = *has_died = \&last_error;
-
-=head3 last_error
+=head3 get_error
 
 Return last error that was recorded during contract execution,
 or false if there was none.
 
 =cut
 
-sub last_error {
+sub get_error {
     my $self = shift;
-    return $self->{last_error} || '';
+    return $self->{has_error} || '';
 };
 
-=head3 as_tap
+=head3 get_tap
 
 Return a would-be Test::More script output for current contract.
 
 =cut
 
-sub as_tap {
+sub get_tap {
     my ($self, $verbosity) = @_;
 
     $verbosity = 1 unless defined $verbosity;
@@ -318,9 +309,10 @@ sub as_tap {
     return join '', @str;
 };
 
-=head3 signature
+=head3 get_sign
 
-Produce a terse pass/fail summary as a string of numbers and letters.
+Produce a terse pass/fail summary (signature)
+as a string of numbers and letters.
 
 The format is C<"t(\d+|N)*[rdE]">.
 
@@ -348,7 +340,7 @@ The numeric notation was inspired by Forsyth-Edwards notation (FEN) in chess.
 
 =cut
 
-sub signature {
+sub get_sign {
     my $self = shift;
 
     my @t = ("t");
@@ -365,28 +357,22 @@ sub signature {
     };
     push @t, $streak if $streak;
 
-    my $d = $self->last_error ? 'E' : $self->{done} ? 'd' : 'r';
+    my $d = $self->get_error ? 'E' : $self->{done} ? 'd' : 'r';
     return join '', @t, $d;
 };
 
-sub _croak {
-    my ($self, $mess) = @_;
-
-    $mess ||= "Something terrible happened";
-    $mess =~ s/\n+$//s;
-
-    my $fun = (caller 1)[3];
-    $fun =~ s/(.*)::/${1}->/;
-
-    croak "$fun(): $mess";
-};
-
 =head2 DEVELOPMENT PRIMITIVES
 
 Generally one should not touch these methods unless
 when subclassing to build a new test backend.
 
-=head3 log_message( $indent, $level, $message )
+When extending this module,
+please try to stick to C<do_*>, C<get_*>, and C<set_*>
+to avoid clash with test names.
+
+This is weird and probably has to be fixed at some point.
+
+=head3 do_log( $indent, $level, $message )
 
 Append a message to execution log.
 Levels are:
@@ -407,7 +393,7 @@ Levels are:
 
 =cut
 
-sub log_message {
+sub do_log {
     my ($self, $indent, $level, @parts) = @_;
 
     $self->_croak( $ERROR_DONE )
@@ -439,13 +425,13 @@ sub get_log {
     return $self->{mess};
 };
 
-=head3 add_result( $id, $result )
+=head3 set_result( $id, $result )
 
 Add a refutation to the failed tests log.
 
 =cut
 
-sub add_result {
+sub set_result {
     my ($self, $id, $result) = @_;
 
     $self->_croak( $ERROR_DONE )
@@ -472,6 +458,65 @@ sub get_proxy {
     return wantarray ? ($self, $self->{indent}) : $self;
 };
 
+sub _croak {
+    my ($self, $mess) = @_;
+
+    $mess ||= "Something terrible happened";
+    $mess =~ s/\n+$//s;
+
+    my $fun = (caller 1)[3];
+    $fun =~ s/(.*)::/${1}->/;
+
+    croak "$fun(): $mess";
+};
+
+=head2 DEPRECATED METHODS
+
+The following methods were added in the beginning and will disappear
+in 0.10.
+
+=over
+
+=item count       => "get_count"
+
+=item add_result  => "set_result"
+
+=item result      => "get_result"
+
+=item last_error  => "get_error"
+
+=item signature   => "get_sign"
+
+=item as_tap      => "get_tap"
+
+=item log_message => "do_log"
+
+=back
+
+=cut
+
+_deprecate( count       => "get_count" );
+_deprecate( add_result  => "set_result" );
+_deprecate( result      => "get_result" );
+_deprecate( last_error  => "get_error" );
+_deprecate( signature   => "get_sign" );
+_deprecate( as_tap      => "get_tap" );
+_deprecate( log_message => "do_log" );
+
+sub _deprecate {
+    my ($legacy, $new) = @_;
+
+    my $impl = \&$new;
+
+    no strict 'refs';           ## no critic
+    no warnings 'redefine';     ## no critic
+    *$legacy = sub {
+        carp "$legacy() is deprecated, use $new() instead";
+        *$legacy = $impl;
+        goto &$impl;            ## no critic
+    };
+};
+
 =head1 LICENSE AND COPYRIGHT
 
 This module is part of L<Assert::Refute> suite.
