@@ -3,7 +3,7 @@ package Assert::Refute::T::Basic;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = 0.0305;
+our $VERSION = 0.04;
 
 =head1 NAME
 
@@ -253,15 +253,15 @@ sub _isa_ok {
 
 Check that a contract has been fullfilled to exactly the specified extent.
 
-See L<Assert::Refute::Exec/signature> for exact signature format.
+See L<Assert::Refute::Exec/get_sign> for exact signature format.
 
 =cut
 
 build_refute contract_is => sub {
     my ($c, $sig) = @_;
 
-    my $got = $c->signature;
-    return $got ne $sig && <<"EOF".$c->as_tap;
+    my $got = $c->get_sign;
+    return $got ne $sig && <<"EOF".$c->get_tap;
 Unexpected subcontract signature.
 Got:      $got
 Expected: $sig
